@@ -4,7 +4,8 @@
 #'
 #' @param option A character scalar of commonly used admiral function inputs.
 #'
-#'   As of now, support only available for `r enumerate(names(admiral_environment$admiral_options), quote_fun = dquote, conjunction = "or")`.
+#'   As of now, support only available for
+#'   `r enumerate(names(admiral_environment$admiral_options), quote_fun = dquote, conjunction = "or")`.
 #'   See `set_admiral_options()` for a description of the options.
 #'
 #' @details
@@ -24,20 +25,32 @@
 #'  [derive_var_dthcaus()], [derive_var_extreme_dtm()], [derive_vars_period()],
 #'  [create_period_dataset()]
 #'
-#'
 #' @examples
-#' library(admiral.test)
 #' library(dplyr, warn.conflicts = FALSE)
-#' data("admiral_vs")
-#' data("admiral_dm")
+#' dm <- tribble(
+#'   ~STUDYID, ~DOMAIN,  ~USUBJID, ~AGE,   ~AGEU,
+#'   "PILOT01",   "DM", "01-1302",   61, "YEARS",
+#'   "PILOT01",   "DM", "17-1344",   64, "YEARS"
+#' )
+#'
+#' vs <- tribble(
+#'   ~STUDYID,  ~DOMAIN,  ~USUBJID, ~VSTESTCD,     ~VISIT,     ~VSTPT, ~VSSTRESN,
+#'   "PILOT01",    "VS", "01-1302",   "DIABP", "BASELINE",    "LYING",        76,
+#'   "PILOT01",    "VS", "01-1302",   "DIABP", "BASELINE", "STANDING",        87,
+#'   "PILOT01",    "VS", "01-1302",   "DIABP",   "WEEK 2",    "LYING",        71,
+#'   "PILOT01",    "VS", "01-1302",   "DIABP",   "WEEK 2", "STANDING",        79,
+#'   "PILOT01",    "VS", "17-1344",   "DIABP", "BASELINE",    "LYING",        88,
+#'   "PILOT01",    "VS", "17-1344",   "DIABP", "BASELINE", "STANDING",        86,
+#'   "PILOT01",    "VS", "17-1344",   "DIABP",   "WEEK 2",    "LYING",        84,
+#'   "PILOT01",    "VS", "17-1344",   "DIABP",   "WEEK 2", "STANDING",        82
+#' )
 #'
 #' # Merging all dm variables to vs
 #' derive_vars_merged(
-#'   admiral_vs,
-#'   dataset_add = select(admiral_dm, -DOMAIN),
+#'   vs,
+#'   dataset_add = select(dm, -DOMAIN),
 #'   by_vars = get_admiral_option("subject_keys")
-#' ) %>%
-#'   select(STUDYID, USUBJID, VSTESTCD, VISIT, VSTPT, VSSTRESN, AGE, AGEU)
+#' )
 get_admiral_option <- function(option) {
   # Check for valid option - catch function abuse
   assert_character_scalar(option)
@@ -65,11 +78,6 @@ get_admiral_option <- function(option) {
 #'   `exprs(STUDYID, USUBJID)`. This option is used as default value for the
 #'   `subject_keys` argument in all admiral functions.
 #'
-#' @param force_admiral_vars If this option is set to `TRUE` (which is the
-#'   default), the admiral definition of `vars()` is forced. This is just a
-#'   temporary solution to allow running scripts which use `vars()` in the
-#'   admiral function calls. It will be removed in a future release.
-#'
 #' @details
 #' Modify an admiral option, e.g `subject_keys`, such that it automatically affects downstream
 #' function inputs where `get_admiral_option()` is called such as `derive_param_exist_flag()`.
@@ -84,7 +92,8 @@ get_admiral_option <- function(option) {
 #' @export
 #'
 #' @seealso [get_admiral_option()], [derive_param_exist_flag()],[derive_param_tte()],
-#' [derive_var_dthcaus()], [derive_var_extreme_dtm()], [derive_vars_period()], [create_period_dataset()]
+#' [derive_var_dthcaus()], [derive_var_extreme_dtm()], [derive_vars_period()],
+#' [create_period_dataset()]
 #'
 #' @examples
 #' library(lubridate)
@@ -102,11 +111,11 @@ get_admiral_option <- function(option) {
 #'   mutate(STUDYID = "XX1234")
 #'
 #' tu <- tribble(
-#'   ~USUBJID2, ~VISIT,      ~TUSTRESC,
-#'   "1",       "SCREENING", "TARGET",
-#'   "1",       "WEEK 1",    "TARGET",
-#'   "1",       "WEEK 5",    "TARGET",
-#'   "1",       "WEEK 9",    "NON-TARGET",
+#'   ~USUBJID2,      ~VISIT,    ~TUSTRESC,
+#'   "1",       "SCREENING",     "TARGET",
+#'   "1",          "WEEK 1",     "TARGET",
+#'   "1",          "WEEK 5",     "TARGET",
+#'   "1",          "WEEK 9", "NON-TARGET",
 #'   "2",       "SCREENING", "NON-TARGET",
 #'   "2",       "SCREENING", "NON-TARGET"
 #' ) %>%
@@ -116,7 +125,7 @@ get_admiral_option <- function(option) {
 #'   )
 #'
 #' derive_param_exist_flag(
-#'   dataset_adsl = adsl,
+#'   dataset_ref = adsl,
 #'   dataset_add = tu,
 #'   filter_add = TUTESTCD == "TUMIDENT" & VISIT == "SCREENING",
 #'   condition = TUSTRESC == "TARGET",
@@ -127,17 +136,12 @@ get_admiral_option <- function(option) {
 #'     PARAM = "Measurable Disease at Baseline"
 #'   )
 #' )
-set_admiral_options <- function(subject_keys, force_admiral_vars) {
+set_admiral_options <- function(subject_keys) {
   if (!missing(subject_keys)) {
     assert_vars(subject_keys)
     admiral_environment$admiral_options$subject_keys <- subject_keys
   }
 
-  if (!missing(force_admiral_vars)) {
-    assert_logical_scalar(force_admiral_vars)
-    admiral_environment$admiral_options$force_admiral_vars <- force_admiral_vars
-  }
-
   # Add future input to function formals above
   # if (!missing(future_input)) {
   #   assert_vars(future_input) nolint
